@@ -28,6 +28,13 @@ proc BasicTest::printOutput { msg  { title "Warning"} { translate 0} { no_new_li
     }
 }
 
+proc BasicTest::printOutputDebug { msg  { title "Warning"} { translate 0} { no_new_line 0} } {
+    variable m_write_in_debug_file
+    if { $m_write_in_debug_file || $BasicTest::m_messages_in_stdout} {
+        BasicTest::printOutput $msg $title $translate $no_new_line
+    }
+}
+
 proc BasicTest::printDynamicLibraryPaths {} {
     if { $::tcl_platform(platform) != "windows" } {
         if { $::tcl_platform(os) != "Darwin" } {
@@ -817,6 +824,7 @@ proc test_pre_import { } {
         if { [ info exists ext2cmd($ext,Category)]} {
             # no new-line: final 1
             BasicTest::printOutput "$str_idx. testing $ext2cmd($ext,Category) ... " "basic test" 0 1
+            BasicTest::printOutputDebug "   filename = $just_name"
             test_new_project
             set result_txt [ test_single_import $ext2cmd($ext,Category) $import_file $ext2cmd($ext,Command)]
             BasicTest::printOutput $result_txt
@@ -912,6 +920,7 @@ proc test_post_import { } {
         if { [ info exists ext2cmd($ext,Category)]} {
             # no new-line: final 1
             BasicTest::printOutput "testing $ext2cmd($ext,Category) ... " "basic test" 0 1
+            BasicTest::printOutputDebug "   filename = $just_name"
             test_new_project
             GiD_Process Mescape Postprocess escape escape escape escape
             if { $just_name == "manual-beam-shell.post.h5"} {
